==> jc-1.4.0.tar.gz: gnu/java/net/protocol/http/HTTPURLConnection__24GetHTTPPropertiesAction.h <==
// class gnu.java.net.protocol.http.HTTPURLConnection$GetHTTPPropertiesAction

// class file dependencies
// @dep_class da4b057bc57b607 gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction_H_
#define _JC_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_refs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_nonrefs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$refs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$refs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$nonrefs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$object	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$object;

typedef const struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vmethods	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtable	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtype	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$method$_init$60d835178deab25d(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$object *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vmethods	gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_refs {
	struct _jc_gnu_java_net_protocol_http_HTTPURLConnection$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$refs {
    _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_refs	gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_nonrefs	gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$object {
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtype _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction_H_ */

==> jc-1.4.5.tar.gz: gnu/java/net/protocol/http/HTTPURLConnection__24GetHTTPPropertiesAction.h <==
// class gnu.java.net.protocol.http.HTTPURLConnection$GetHTTPPropertiesAction

// class file dependencies
// @dep_class d7787a3230807fbe gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction_H_
#define _JC_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_refs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_nonrefs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$refs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$refs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$nonrefs	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$object	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$object;

typedef const struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vmethods	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtable	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtype	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$method$_init$60d835178deab25d(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$object *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vmethods	gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_refs {
	struct _jc_gnu_java_net_protocol_http_HTTPURLConnection$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$refs {
    _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_refs	gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$sub_nonrefs	gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$object {
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$vtype _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_HTTPURLConnection__24GetHTTPPropertiesAction_H_ */
